Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2604)

Unified Diff: chrome/browser/extensions/extension_tabs_module.cc

Issue 4090011: Fix bug with context menus in incognito mode. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: manifest fix Created 10 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/extensions/extension_tabs_module.cc
diff --git a/chrome/browser/extensions/extension_tabs_module.cc b/chrome/browser/extensions/extension_tabs_module.cc
index ce3a92a05bb6c587a65d181d1317fa128e5117c1..e1a72a1cad702564b92bd52a2edcd97f09096ac4 100644
--- a/chrome/browser/extensions/extension_tabs_module.cc
+++ b/chrome/browser/extensions/extension_tabs_module.cc
@@ -600,9 +600,10 @@ bool CreateTabFunction::RunImpl() {
EXTENSION_FUNCTION_VALIDATE(args->GetBoolean(keys::kSelectedKey,
&selected));
// We can't load extension URLs into incognito windows. Special case to
// fall back to a normal window.
if (url.SchemeIs(chrome::kExtensionScheme) &&
+ !GetExtension()->incognito_split_mode() &&
browser->profile()->IsOffTheRecord()) {
Profile* profile = browser->profile()->GetOriginalProfile();
browser = BrowserList::FindBrowserWithType(profile,
@@ -600,9 +600,10 @@ bool CreateTabFunction::RunImpl() {
EXTENSION_FUNCTION_VALIDATE(args->GetBoolean(keys::kSelectedKey,
&selected));
- // We can't load extension URLs into incognito windows. Special case to
- // fall back to a normal window.
+ // We can't load extension URLs into incognito windows unless the extension
+ // uses split mode. Special case to fall back to a normal window.
if (url.SchemeIs(chrome::kExtensionScheme) &&

Powered by Google App Engine
This is Rietveld 408576698